<?php
/**
 * @package ats
 * @copyright Copyright (c)2011-2018 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license GNU GPL v3 or later
 */

/** @var    FOF30\View\DataView\Html    $this */
defined('_JEXEC') or die;

use Akeeba\TicketSystem\Admin\Helper\ComponentParams;
use Akeeba\TicketSystem\Admin\Helper\Editor;
use Akeeba\TicketSystem\Admin\Helper\Html;
use Akeeba\TicketSystem\Admin\Helper\Permissions;
use Akeeba\TicketSystem\Admin\Helper\Select;

/*
 * Params passed by the loadAnyTemplate function
 *
 * $category            : Category id
 * $direct              : ???
 * $allow_attachment    : Are attachments allowed?
 * $post_content        : Content of the post stored in the session (previous failed save)
 */

if(!isset($category))           $category = 0;
if(!isset($direct))             $direct = false;
if(!isset($allow_attachment))   $allow_attachment = false;
if(!isset($post_content))       $post_content = '';

JHtml::_('formbehavior.chosen');
JHTML::_('behavior.tooltip');
JHTML::_('behavior.modal');

$isAdmin       = $this->container->platform->getUser()->authorise('core.admin', 'com_ats') || $this->container->platform->getUser()->authorise('core.manage', 'com_ats');
$isManager     = Permissions::isManager($category);
$uploadLimit   = Html::getUploadLimits();
$allowedExt    = Html::allowedExtensions();
$moduleContent = '';

if (!$isManager)
{
    $moduleContent = Html::loadposition('ats-replyarea-overlay');
}

$tags = array();

if ($this->item->created_by)
{
	// First fetch the tags from the legacy storage
    // TODO This will be removed in future versions when we completed the migration of the tags
	/** @var \Akeeba\TicketSystem\Admin\Model\UserTags $tagModel */
    $tagModel = $this->container->factory->model('UserTags')->tmpInstance();
    $tags     = $tagModel->loadTagsByUser($this->item->created_by);

	// Then merge them with the new way
	/** @var \Akeeba\TicketSystem\Site\Model\Jusers $joomlaModel */
	$joomlaModel = $this->getModel('Jusers');
	$joomlaModel->find($this->item->created_by);

	/** @var \FOF30\Model\DataModel\Collection $collection */
	$collection = $joomlaModel->atstags;
	$tags = array_merge($tags, $collection->modelKeys());
	$tags = array_unique($tags);
}

if ($allow_attachment)
{
    $js = <<<JS
akeeba.jQuery(document).ready(function(jQuery){
    jQuery('#addAttachment').click(function(){
        if(jQuery('input[name="attachedfile[]"]').length >= 10)
        {
            return false;
        }

        var clone = jQuery('.ats-ticket-replyarea-attachment').first().clone();
        clone.children('label').html('').addClass('col-xs-0');
        clone.children('.attFileField').children().first().val('');
        clone.children('div').children('.attButtonField').children().first().css('display', 'inline-block');

        clone.appendTo('.ats-attachments');
    })

});

JS;

    $this->container->template->addJSInline($js);
}

$timespentMandatory = $this->getContainer()->params->get('timespent_mandatory', 0);

?>
<?php if(!empty($moduleContent)): ?>
    <div id="ats-replyarea-overlay">
        <?php echo $moduleContent ?>
        <p>
            <a href="javascript:void(0);" id="ats-replyarea-overlay-close" class="btn btn-success">
                <i class="icon-ok icon-white"></i>
                <?php echo JText::_('COM_ATS_NEWTICKET_INSTANTREPLY_CLOSEMESSAGE'); ?>
            </a>
        </p>
    </div>
<?php endif ?>

<?php if(Editor::isEditorBBcode()): ?>
    <div class="ats-ticket-content-info help-block">
        <?php echo JText::_('COM_ATS_NEWTICKET_LBL_YOURREQUEST_INFO'); ?>
    </div>
<?php endif; ?>

    <?php if($isManager): ?>
        <?php if(ATS_PRO): ?>
        <div class="control-group form-group" style="margin: 5px 0">
            <label for="ats-timespent" class="control-label col-sm-3"><?php echo JText::_('COM_ATS_POSTS_LBL_TIMESPENT'); ?></label>
            <div class="controls col-sm-9">
				<span class="input-append input-group col-sm-3">
					<input type="text" name="timespent" id="ats-timespent" <?php echo $timespentMandatory ? 'required="required"' : '' ?> class="input-small form-control input-sm" value="" />
					<span class="add-on input-group-addon"><?php echo JText::_('COM_ATS_POSTS_LBL_TIMESPENT_MINUTES') ?></span>
				</span>

                <span class="btn" id="timerBtn"><?php echo JText::_('COM_ATS_TIMER_START')?></span>
                <img id="counting" style="display:none" src="<?php echo $this->getContainer()->template->parsePath('media://com_ats/images/throbber.gif')?>">
            </div>
        </div>
        <?php endif; ?>
    <?php endif; ?>

    <div class="ats-ticket-replyarea-content bbcode">
        <?php
        $contents = '';

        if(Editor::isEditorBBcode())
        {
            $name = $direct ? 'content' : 'post[content]';
            $id = 'bbcode';
        }
        else
        {
            $name = $direct ? 'content_html' : 'post[content_html]';
            $id = 'ats-content';
        }

        $params 				 = array();
        $params['buckets']  	 = $isAdmin && ATS_PRO;
        $params['ats_ticket_id'] = $this->item->ats_ticket_id;

        if($isManager)
        {
            $params['cannedreplies'] = true;

            if (isset($category))
            {
                $params['category'] = $category;
            }
        }

        Editor::showEditor($name, $id, $post_content, '95%', 400, 80, 20, $params);
        ?>
    </div>

<?php if($isManager || $allow_attachment): ?>
    <div class="ats-clear"></div>
    <div class="form-horizontal">
<?php endif; ?>

<?php if($isManager): ?>
    <?php if(ATS_PRO): ?>
        <?php if(ComponentParams::getParam('showcredits', 0)):?>
            <div class="control-group form-group">
                <label for="ats-credits-charge" class="control-label col-sm-3"><?php echo JText::_('COM_ATS_POSTS_CREDITS_CHARGE')?></label>
                <div class="controls col-sm-9">
				<span class="input-append input-group col-sm-3">
					<input type="text" name="extracredits" id="ats-credits-charge" class="input-small form-control" value="" />
					<span class="add-on input-group-addon"><?php echo JText::_('COM_ATS_TICKETS_USERINFO_CREDITS') ?></span>
				</span>
                </div>
            </div>
        <?php endif;?>
    <?php endif; ?>
    <div class="control-group form-group">
        <label for="usertags" class="control-label col-sm-3"><?php echo JText::_('COM_ATS_COMMON_USER_TAGS')?></label>
        <div class="controls col-sm-9">
            <?php echo Select::usertags('usertags[]', $tags, array('class' => 'advancedSelect input-large form-control', 'multiple' => 'multiple', 'size' => 5))?>
        </div>
    </div>
<?php endif; ?>

<?php if($allow_attachment): ?>
    <div class="ats-ticket-replyarea-attachment control-group form-group">
        <label for="attachedfile" class="control-label col-sm-3"><?php echo JText::_('COM_ATS_NEWTICKET_LBL_ATTACHMENT'); ?></label>
        <div class="controls">
            <span class="col-sm-6 attFileField">
                <input type="file" name="attachedfile[]" class="form-control col-sm-6" />
            </span>
            <span class="col-sm-3 attButtonField">
                <a class="btn btn-mini btn-inverse btn-xs btn-default" href="javascript:void(0);" onclick="akeeba.jQuery(this).parent().parent().parent().remove();" style="display: none;"><?php echo JText::_('COM_ATS_COMMON_REMOVE')?></a>
            </span>
        </div>
    </div>

    <div class="ats-attachments"></div>

    <div class="ats-ticket-replyarea-attachment-help control-group form-group">
        <label class="control-label col-sm-3">&nbsp;</label>
        <div class="col-sm-9 col-xs-12">
            <a href="javascript:void(0);" class="btn btn-default" id="addAttachment">
                <span class="icon icon-plus-sign glyphicon glyphicon-plus-sign"></span>
                <?php echo JText::_('COM_ATS_POSTS_ADD_ATTACHMENT')?>
            </a>
                <span class="help-block">
                    <?php echo JText::sprintf('COM_ATS_NEWTICKET_LBL_ATTACHMENT_MAXSIZE',$uploadLimit); ?>
                </span>
                <span class="help-block">
                    <?php echo JText::sprintf('COM_ATS_NEWTICKET_LBL_ATTACHMENT_ALLOWED_EXTENSIONS', implode(', ',$allowedExt)); ?>
                </span>
        </div>
    </div>
<?php endif; ?>

<?php if($isManager || $allow_attachment): ?>
    </div>
<?php endif; ?>

<?php
if(!empty($moduleContent))
{
	$this->addJavascriptInline( <<<JS

;// This comment is intentionally put here to prevent badly written plugins from causing a Javascript error
// due to missing trailing semicolon and/or newline in their code.
(function($) {
	$(document).ready(function()	{
		$('#ats-replyarea-overlay-close').click(function(e){
			$('#ats-replyarea-overlay').hide();
		});
	});
})(akeeba.jQuery);
JS
    );
}
