<?php
/**
 * @package ats
 * @copyright Copyright (c)2011-2018 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license GNU GPL v3 or later
 */

/** @var FOF30\View\DataView\Html $this */

use Akeeba\TicketSystem\Admin\Helper\Filter;
use Akeeba\TicketSystem\Admin\Helper\Html;
use Akeeba\TicketSystem\Admin\Helper\Subscriptions;

defined('_JEXEC') or die;

$container   = $this->getContainer();
$container->platform->importPlugin('ats');
$avatarURL   = Html::getAvatarURL($user, 64);
$subsPerUser = Subscriptions::getSubscriptionsList($user);

?>
<?php if($avatarURL): ?>
<div class="ats-post-userinfo-avatar">
	<img src="<?php echo $avatarURL?>" />
</div>
<?php endif; ?>
<div class="ats-post-userinfo-username">
    <?php if($this->isManager):
    $count = Html::getTicketsCount($user->id);
    $link  = JRoute::_('index.php?option=com_ats&view=Mies&userid='.$user->id);
    ?>
    <a href="<?php echo $link ?>"><?php echo $user->username ?></a>
    <span class="badge hasTooltip" title="<?php echo JText::sprintf('COM_ATS_TICKET_LBL_HADFILEDXTICKETS', $count)?>">
        <?php echo $count; ?>
    </span>
    <?php else: ?>
    <?php echo $user->username ?>
    <?php endif; ?>

    <?php if($this->isManager):
    $timeSpent = Html::getTimeSpentPerUser($user->id);?>
    <span class="badge hasTooltip badge-info" title="<?php echo JText::sprintf('COM_ATS_TICKET_LBL_HAVESPENTXMINUTES', $timeSpent)?>">
        <?php echo $timeSpent ?>'
    </span>
    <?php endif; ?>
</div>
<div class="ats-post-userinfo-badge">
<?php foreach($user->groups as $groupName => $groupID):
	$basePath = JPATH_ROOT.'/media/com_ats/groups/';
	$altPath  = JPATH_BASE.'/templates/'.JFactory::getApplication()->getTemplate().'/media/com_ats/groups/';
	$alias    = Filter::toSlug($groupName);

	$img      = null;

	if(JFile::exists($altPath.$alias.'.png') || JFile::exists($basePath.$alias.'.png'))
    {
		$img = $container->template->parsePath('media://com_ats/groups/'.$alias.'.png');
	}
    elseif(JFile::exists($altPath.$alias.'.jpg') || JFile::exists($basePath.$alias.'.jpg'))
    {
		$img = $container->template->parsePath('media://com_ats/groups/'.$alias.'.jpg');
	}

	if(!is_null($img)):
?>
	<img src="<?php echo $img?>" border="0" />
<?php
	endif;
	endforeach; ?>
</div>
<?php
$countryInfo  = null;
$pluginResult = $container->platform->runPlugins('onAtsGetSubscriptionCountry', array($user->id, $this->isManager));

if(is_array($pluginResult))
{
	$countryInfo = array_shift($pluginResult);
}

if(!empty($countryInfo) && is_array($countryInfo) && (count($countryInfo) > 1)): ?>
<div class="ats-post-userinfo-flag">
    <img class="hasTooltip" src="<?php echo $container->template->parsePath('media://com_ats/flags/' . strtolower($countryInfo[0]) . '.gif') ?>" title="<?php echo $countryInfo[1] ?>" alt="<?php echo $countryInfo[1] ?>" />
</div>
<?php endif;?>
<?php
    // User tags
    if($this->isManager)
    {
	    if($subsPerUser->active): ?>
        <div class="ats-post-userinfo-subscriptions">
		    <?php echo implode(', ', $subsPerUser->active) ?>
        </div>
    <?php
        endif;
	    /** @var \Akeeba\TicketSystem\Site\Model\Jusers $juserModel */
	    $juserModel = $this->getModel('Jusers');

	    // Load the model only if the user is different. Since it's always the same user, this happens only the first time
        // In this way we can cache the data inside relationships, avoiding unnecessary queries
	    if ($juserModel->id != $user->id)
        {
	        $juserModel->find($user->id);
        }

	    $tags = $juserModel->atstags;

        foreach($tags as $tag)
        {
        ?>
        <span class="label label-info atsTooltip" data-toggle="tooltip" title="<?php echo $tag->title?>">
            <?php echo $tag->title ?>
        </span>
    <?php
        }
    }
?>
